# package_name

`` is a Python library for Rocket,Circle and Shuffle

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `linereg`.

```bash
pip install linereg
```

## Usage

```python
import linereg

# returns 'words'
linereg.module_name('word')

# returns 'geese'
linereg.module_name('goose')

# returns 'phenomenon'
linereg.module_name('phenomena')
```

## License

[MIT](https://choosealicense.com/licenses/mit/)
